#
# Conditional build:
%bcond_with	kernel		# backfire kernel module
%bcond_without	userspace	# userspace programs
%bcond_with	verbose		# verbose kernel module build (V=1)

%if 0%{?_pld_builder:1} && %{with kernel} && %{with userspace}
%{error:kernel and userspace cannot be built at the same time on PLD builders}
exit 1
%endif

%if %{without userspace}
%define		_enable_debug_packages	0
%endif

Summary:	Programs that test various rt-linux features
Summary(pl.UTF-8):	Programy testujące różne właściwości rt-linuksa
%define	pname	rt-tests
Name:		%{pname}%{?_pld_builder:%{?with_kernel:-kernel}}%{_alt_kernel}
Version:	2.8
%define	rel	4
Release:	%{rel}%{?_pld_builder:%{?with_kernel:@%{_kernel_ver_str}}}
License:	GPL v2
Group:		Applications/System
Source0:	https://www.kernel.org/pub/linux/utils/rt-tests/%{pname}-%{version}.tar.xz
# Source0-md5:	470d1c23ec4ca81a2ab63f3c6caa7a1e
# https://bugs.launchpad.net/ubuntu/+source/rt-tests/+bug/881771/+attachment/2572753/+files/0001-Fix-deprecated-removed-spinlock-declaration.patch
# + http://www.spinics.net/lists/linux-rt-users/msg08966.html
Patch0:		%{pname}-backfire.patch
# https://git.kernel.org/pub/scm/utils/rt-tests/rt-tests.git/patch/?id=d3a23a0cc76789c3083df3bad78982cd49bc4c5e
Patch1:		%{pname}-glibc2.41.patch
URL:		https://rt.wiki.kernel.org/index.php/Cyclictest
%{?with_kernel:%{expand:%buildrequires_kernel kernel%%{_alt_kernel}-module-build >= 3:2.6.20.2}}
%ifarch %{ix86} %{x8664} x32 ia64 mips ppc
BuildRequires:	numactl-devel
%endif
BuildRequires:	python3-modules >= 1:3
BuildRequires:	rpmbuild(macros) >= 1.701
BuildRequires:	sed >= 4.0
BuildRequires:	tar >= 1:1.22
BuildRequires:	xz
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
Programs that test various rt-linux features.

%description -l pl.UTF-8
Programy testujące różne właściwości rt-linuksa.

%define	kernel_pkg()\
%package -n kernel%{_alt_kernel}-char-backfire\
Summary:	Linux kernel module to benchmark signal delivery\
Summary(pl.UTF-8):	Moduł jądra Linuksa do testowania dostarczania sygnałów\
Release:	%{rel}@%{_kernel_ver_str}\
Group:		Base/Kernel\
Requires(post,postun):	/sbin/depmod\
%requires_releq_kernel\
Requires(postun):	%releq_kernel\
\
%description -n kernel%{_alt_kernel}-char-backfire\
Linux kernel "backfire" module sends a signal from driver to user.\
It's primary use is benchmarking signal delivery.\
\
%description -n kernel%{_alt_kernel}-char-backfire -l pl.UTF-8\
Moduł jądra Linuksa "backfire" wysyła sygnał ze sterownika do\
użytkownika. Głównym zastosowaniem jest testowanie wydajności\
dostarczania sygnałów.\
\
%if %{with kernel}\
%files -n kernel%{_alt_kernel}-char-backfire\
%defattr(644,root,root,755)\
/lib/modules/%{_kernel_ver}/kernel/drivers/char/backfire.ko*\
%endif\
\
%post	-n kernel%{_alt_kernel}-char-backfire\
%depmod %{_kernel_ver}\
\
%postun	-n kernel%{_alt_kernel}-char-backfire\
%depmod %{_kernel_ver}\
%{nil}

%define build_kernel_pkg()\
%build_kernel_modules -C src/backfire -m backfire\
\
%install_kernel_modules -D installed -m src/backfire/backfire -d kernel/drivers/char\
%{nil}

%{?with_kernel:%{expand:%create_kernel_packages}}

%prep
%setup -q -n %{pname}-%{version}
%patch -P0 -p1
%patch -P1 -p1

%{__sed} -i -e '1s,/usr/bin/env python3,%{__python3},' src/cyclictest/get_cyclictest_snapshot.py

%build
%if %{with userspace}
CFLAGS="%{rpmcflags}" \
%{__make} \
	prefix="%{_prefix}" \
	CC="%{__cc}" \
	LDFLAGS="%{rpmldflags}"
%endif

%{?with_kernel:%{expand:%build_kernel_packages}}

%install
rm -rf $RPM_BUILD_ROOT

%if %{with userspace}
%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT \
	prefix="%{_prefix}" \
	PYLIB="%{py3_sitescriptdir}"

%py3_comp $RPM_BUILD_ROOT%{py3_sitescriptdir}
%py3_ocomp $RPM_BUILD_ROOT%{py3_sitescriptdir}
%endif

%if %{with kernel}
cp -a installed/* $RPM_BUILD_ROOT
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc README.markdown MAINTAINERS
%attr(755,root,root) %{_bindir}/cyclicdeadline
%attr(755,root,root) %{_bindir}/cyclictest
%attr(755,root,root) %{_bindir}/deadline_test
%attr(755,root,root) %{_bindir}/determine_maximum_mpps.sh
%attr(755,root,root) %{_bindir}/get_cyclictest_snapshot
%attr(755,root,root) %{_bindir}/hackbench
%attr(755,root,root) %{_bindir}/hwlatdetect
%attr(755,root,root) %{_bindir}/oslat
%attr(755,root,root) %{_bindir}/pi_stress
%attr(755,root,root) %{_bindir}/pip_stress
%attr(755,root,root) %{_bindir}/pmqtest
%attr(755,root,root) %{_bindir}/ptsematest
%attr(755,root,root) %{_bindir}/queuelat
%attr(755,root,root) %{_bindir}/rt-migrate-test
%attr(755,root,root) %{_bindir}/signaltest
%attr(755,root,root) %{_bindir}/sigwaittest
%attr(755,root,root) %{_bindir}/ssdd
%attr(755,root,root) %{_bindir}/svsematest
%{py3_sitescriptdir}/hwlatdetect.py
%{py3_sitescriptdir}/get_cyclictest_snapshot.py
%{py3_sitescriptdir}/__pycache__/hwlatdetect.cpython-*.py[co]
%{py3_sitescriptdir}/__pycache__/get_cyclictest_snapshot.cpython-*.py[co]
%{_mandir}/man8/cyclicdeadline.8*
%{_mandir}/man8/cyclictest.8*
%{_mandir}/man8/deadline_test.8*
%{_mandir}/man8/determine_maximum_mpps.8*
%{_mandir}/man8/get_cyclictest_snapshot.8*
%{_mandir}/man8/hackbench.8*
%{_mandir}/man8/hwlatdetect.8*
%{_mandir}/man8/oslat.8*
%{_mandir}/man8/pi_stress.8*
%{_mandir}/man8/pip_stress.8*
%{_mandir}/man8/pmqtest.8*
%{_mandir}/man8/ptsematest.8*
%{_mandir}/man8/queuelat.8*
%{_mandir}/man8/rt-migrate-test.8*
%{_mandir}/man8/signaltest.8*
%{_mandir}/man8/sigwaittest.8*
%{_mandir}/man8/ssdd.8*
%{_mandir}/man8/svsematest.8*
%changelog
* Tue Apr 01 2025 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/rt-tests.git;a=log;h=master

* Tue Apr 01 2025 Jakub Bogusz <qboosh@pld-linux.org> 9475ca1
- added fix for glibc 2.41 from git; release 4

* Tue Mar 11 2025 Jan Rękorajski <baggins@pld-linux.org> f8f5ab8
- Release 3 (by relup.sh)

* Mon Mar 10 2025 Jan Rękorajski <baggins@pld-linux.org> da6b120
- python 3.13 rebuild

* Mon Jan 27 2025 Jakub Bogusz <qboosh@pld-linux.org> 060bba3
- updated to 2.8

* Tue May 21 2024 Jakub Bogusz <qboosh@pld-linux.org> 30eddfc
- up to 2.7

* Wed Oct 18 2023 Jakub Bogusz <qboosh@pld-linux.org> 0c1c330
- updated to 2.6

* Thu Mar 30 2023 Jakub Bogusz <qboosh@pld-linux.org> e241c36
- updated to 2.5

* Sun Aug 21 2022 Jakub Bogusz <qboosh@pld-linux.org> 2da8aa6
- updated to 2.4

* Sat Mar 26 2022 Jan Rękorajski <baggins@pld-linux.org> f8f6a0f
- Release 4 (by relup.sh)

* Sat Mar 26 2022 Jan Rękorajski <baggins@pld-linux.org> 4f4cbd2
- disable kernel module bcond

* Sat Mar 26 2022 Jan Rękorajski <baggins@pld-linux.org> 28dbcc1
- rebuild with python 3.10

* Fri Mar 25 2022 Jan Rękorajski <baggins@pld-linux.org> dbae1f1
- rebuild with python 3.10

* Sat Jan 15 2022 Jakub Bogusz <qboosh@pld-linux.org> ae0337e
- updated to 2.3; module still not ready for Linux 5.14+

* Sat Sep 11 2021 Jakub Bogusz <qboosh@pld-linux.org> 74c0026
- updated to 2.2; module seems not ready for kernel 5.14

* Sun Jul 04 2021 Jakub Bogusz <qboosh@pld-linux.org> a1ba0a3
- updated to 2.1

* Wed Mar 03 2021 Jan Rękorajski <baggins@pld-linux.org> c7ed441
- release 2 (by relup.sh)

* Mon Feb 22 2021 Jakub Bogusz <qboosh@pld-linux.org> 72cf62e
- updated to 1.10

* Fri Oct 16 2020 Jakub Bogusz <qboosh@pld-linux.org> bc76765
- updated to 1.9; python3 now

* Thu Jun 04 2020 Jakub Bogusz <qboosh@pld-linux.org> 71591af
- updated to 1.8

* Sun Feb 09 2020 Jakub Bogusz <qboosh@pld-linux.org> 37a5aca
- updated to 1.6
- updated backfire patch

